# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: esdbclient/protos/Grpc/shared.proto
"""Generated protocol buffer code."""
from google.protobuf import (
    descriptor as _descriptor,
    descriptor_pool as _descriptor_pool,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#esdbclient/protos/Grpc/shared.proto\x12\x12\x65vent_store.client\x1a\x1bgoogle/protobuf/empty.proto"\xa9\x01\n\x04UUID\x12\x39\n\nstructured\x18\x01'
    b" \x01(\x0b\x32#.event_store.client.UUID.StructuredH\x00\x12\x10\n\x06string\x18\x02"
    b" \x01(\tH\x00\x1aK\n\nStructured\x12\x1d\n\x15most_significant_bits\x18\x01"
    b" \x01(\x03\x12\x1e\n\x16least_significant_bits\x18\x02"
    b' \x01(\x03\x42\x07\n\x05value"\x07\n\x05\x45mpty"-\n\x10StreamIdentifier\x12\x13\n\x0bstream_name\x18\x03'
    b' \x01(\x0cJ\x04\x08\x01\x10\x03"F\n\x11\x41llStreamPosition\x12\x17\n\x0f\x63ommit_position\x18\x01'
    b" \x01(\x04\x12\x18\n\x10prepare_position\x18\x02"
    b' \x01(\x04"\xf7\x02\n\x14WrongExpectedVersion\x12!\n\x17\x63urrent_stream_revision\x18\x01'
    b" \x01(\x04H\x00\x12\x33\n\x11\x63urrent_no_stream\x18\x02"
    b' \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12"\n\x18\x65xpected_stream_position\x18\x03'
    b" \x01(\x04H\x01\x12.\n\x0c\x65xpected_any\x18\x04"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12\x38\n\x16\x65xpected_stream_exists\x18\x05"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x12\x34\n\x12\x65xpected_no_stream\x18\x06"
    b" \x01(\x0b\x32\x16.google.protobuf.EmptyH\x01\x42"
    b' \n\x1e\x63urrent_stream_revision_optionB!\n\x1f\x65xpected_stream_position_option"\x0e\n\x0c\x41\x63\x63\x65ssDenied"P\n\rStreamDeleted\x12?\n\x11stream_identifier\x18\x01'
    b' \x01(\x0b\x32$.event_store.client.StreamIdentifier"\t\n\x07Timeout"\t\n\x07Unknown"\x14\n\x12InvalidTransaction"2\n\x19MaximumAppendSizeExceeded\x12\x15\n\rmaxAppendSize\x18\x01'
    b' \x01(\r"\x1d\n\nBadRequest\x12\x0f\n\x07message\x18\x01'
    b" \x01(\tB&\n$com.eventstore.dbclient.proto.sharedb\x06proto3"
)


_UUID = DESCRIPTOR.message_types_by_name["UUID"]
_UUID_STRUCTURED = _UUID.nested_types_by_name["Structured"]
_EMPTY = DESCRIPTOR.message_types_by_name["Empty"]
_STREAMIDENTIFIER = DESCRIPTOR.message_types_by_name["StreamIdentifier"]
_ALLSTREAMPOSITION = DESCRIPTOR.message_types_by_name["AllStreamPosition"]
_WRONGEXPECTEDVERSION = DESCRIPTOR.message_types_by_name["WrongExpectedVersion"]
_ACCESSDENIED = DESCRIPTOR.message_types_by_name["AccessDenied"]
_STREAMDELETED = DESCRIPTOR.message_types_by_name["StreamDeleted"]
_TIMEOUT = DESCRIPTOR.message_types_by_name["Timeout"]
_UNKNOWN = DESCRIPTOR.message_types_by_name["Unknown"]
_INVALIDTRANSACTION = DESCRIPTOR.message_types_by_name["InvalidTransaction"]
_MAXIMUMAPPENDSIZEEXCEEDED = DESCRIPTOR.message_types_by_name[
    "MaximumAppendSizeExceeded"
]
_BADREQUEST = DESCRIPTOR.message_types_by_name["BadRequest"]
UUID = _reflection.GeneratedProtocolMessageType(
    "UUID",
    (_message.Message,),
    {
        "Structured": _reflection.GeneratedProtocolMessageType(
            "Structured",
            (_message.Message,),
            {
                "DESCRIPTOR": _UUID_STRUCTURED,
                "__module__": "esdbclient.protos.Grpc.shared_pb2"
                # @@protoc_insertion_point(class_scope:event_store.client.UUID.Structured)
            },
        ),
        "DESCRIPTOR": _UUID,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.UUID)
    },
)
_sym_db.RegisterMessage(UUID)
_sym_db.RegisterMessage(UUID.Structured)

Empty = _reflection.GeneratedProtocolMessageType(
    "Empty",
    (_message.Message,),
    {
        "DESCRIPTOR": _EMPTY,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.Empty)
    },
)
_sym_db.RegisterMessage(Empty)

StreamIdentifier = _reflection.GeneratedProtocolMessageType(
    "StreamIdentifier",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMIDENTIFIER,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.StreamIdentifier)
    },
)
_sym_db.RegisterMessage(StreamIdentifier)

AllStreamPosition = _reflection.GeneratedProtocolMessageType(
    "AllStreamPosition",
    (_message.Message,),
    {
        "DESCRIPTOR": _ALLSTREAMPOSITION,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.AllStreamPosition)
    },
)
_sym_db.RegisterMessage(AllStreamPosition)

WrongExpectedVersion = _reflection.GeneratedProtocolMessageType(
    "WrongExpectedVersion",
    (_message.Message,),
    {
        "DESCRIPTOR": _WRONGEXPECTEDVERSION,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.WrongExpectedVersion)
    },
)
_sym_db.RegisterMessage(WrongExpectedVersion)

AccessDenied = _reflection.GeneratedProtocolMessageType(
    "AccessDenied",
    (_message.Message,),
    {
        "DESCRIPTOR": _ACCESSDENIED,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.AccessDenied)
    },
)
_sym_db.RegisterMessage(AccessDenied)

StreamDeleted = _reflection.GeneratedProtocolMessageType(
    "StreamDeleted",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMDELETED,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.StreamDeleted)
    },
)
_sym_db.RegisterMessage(StreamDeleted)

Timeout = _reflection.GeneratedProtocolMessageType(
    "Timeout",
    (_message.Message,),
    {
        "DESCRIPTOR": _TIMEOUT,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.Timeout)
    },
)
_sym_db.RegisterMessage(Timeout)

Unknown = _reflection.GeneratedProtocolMessageType(
    "Unknown",
    (_message.Message,),
    {
        "DESCRIPTOR": _UNKNOWN,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.Unknown)
    },
)
_sym_db.RegisterMessage(Unknown)

InvalidTransaction = _reflection.GeneratedProtocolMessageType(
    "InvalidTransaction",
    (_message.Message,),
    {
        "DESCRIPTOR": _INVALIDTRANSACTION,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.InvalidTransaction)
    },
)
_sym_db.RegisterMessage(InvalidTransaction)

MaximumAppendSizeExceeded = _reflection.GeneratedProtocolMessageType(
    "MaximumAppendSizeExceeded",
    (_message.Message,),
    {
        "DESCRIPTOR": _MAXIMUMAPPENDSIZEEXCEEDED,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.MaximumAppendSizeExceeded)
    },
)
_sym_db.RegisterMessage(MaximumAppendSizeExceeded)

BadRequest = _reflection.GeneratedProtocolMessageType(
    "BadRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BADREQUEST,
        "__module__": "esdbclient.protos.Grpc.shared_pb2"
        # @@protoc_insertion_point(class_scope:event_store.client.BadRequest)
    },
)
_sym_db.RegisterMessage(BadRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"\n$com.eventstore.dbclient.proto.shared"
    _UUID._serialized_start = 89
    _UUID._serialized_end = 258
    _UUID_STRUCTURED._serialized_start = 174
    _UUID_STRUCTURED._serialized_end = 249
    _EMPTY._serialized_start = 260
    _EMPTY._serialized_end = 267
    _STREAMIDENTIFIER._serialized_start = 269
    _STREAMIDENTIFIER._serialized_end = 314
    _ALLSTREAMPOSITION._serialized_start = 316
    _ALLSTREAMPOSITION._serialized_end = 386
    _WRONGEXPECTEDVERSION._serialized_start = 389
    _WRONGEXPECTEDVERSION._serialized_end = 764
    _ACCESSDENIED._serialized_start = 766
    _ACCESSDENIED._serialized_end = 780
    _STREAMDELETED._serialized_start = 782
    _STREAMDELETED._serialized_end = 862
    _TIMEOUT._serialized_start = 864
    _TIMEOUT._serialized_end = 873
    _UNKNOWN._serialized_start = 875
    _UNKNOWN._serialized_end = 884
    _INVALIDTRANSACTION._serialized_start = 886
    _INVALIDTRANSACTION._serialized_end = 906
    _MAXIMUMAPPENDSIZEEXCEEDED._serialized_start = 908
    _MAXIMUMAPPENDSIZEEXCEEDED._serialized_end = 958
    _BADREQUEST._serialized_start = 960
    _BADREQUEST._serialized_end = 989
# @@protoc_insertion_point(module_scope)
